# Change Log
Notable changes to this project will be documented in this file.

## [Unreleased]
### Added
### Changed
### Deprecated
### Removed
### Fixed
### Security


## [0.1.0]
Bare minimum of [Privacy Pass protocol](https://privacypass.github.io/) to redeem tokens.
### Added
- voprf: derive_key() - Derives the shared key used for redemption MACs
- voprf: create_request_binding()
- privacypass: redemption_token()
- docs: Initial README
- docs: Firefox Token extraction steps in README
- docs: Usage example

[Unreleased]: https://github.com/sergebakharev/privacypass/compare/v0.1.0...HEAD
[0.1.0]: https://github.com/sergebakharev/privacypass/releases/tag/v0.1.0
